
%macro step1;
proc sort data=sasdat.crime2;
  by jid year;

*I use SAS:proc summary,merge in place of STATA:egen,by;
*This is to take care of missing values of censdist in the early;
*years, and just assigns to all obs for a city the maximum of;
*censdist.  If you want, you can check that the max=min, i.e. that the;
*censdist never changes (as it should not).;

proc summary data=sasdat.crime2;
  class jid;
  var censdist;
  output out=holdr(where=(_type_=1)) max=;

data crime2(where=(1973<=year<=1992)
  keep=jid city year cityname name              /*identifiers*/
       dlnc1-dlnc7 dlns_1 dlns_2                /*crimes,cops*/
       elec_1 elec_2 may_1 may_2 gov_1 gov_2    /*elections*/
       dx1-dx6 cs1-cs4 y73-y92 rr1-rr9 cc1-cc59 /*covariates*/
       nobs_1-nobs_7                            /*bookkeeping*/
            );
  /*Note: even though Levitts data set contains cops back to 1969, he
          normalizes by population, which starts in 1970, so dlns_2
          first available in 1973 (since dlns first available in
          1971). Original paper might have people confused on this.*/
  merge sasdat.crime2(drop=censdist where=(1970<=year<=1992))
        holdr(keep=jid censdist);
  by jid;
  retain x 0;    /*initialize x to 0*/
  x=x+first.jid; /*x will range 1-59, indexing cities*/

  pop=citypop;
  dlnp=dif(log(pop));            if first.jid then dlnp=.;

  dlnc1=dif(log(murder))-dlnp;   if first.jid then dlnc1=.;
  dlnc2=dif(log(rape))-dlnp;     if first.jid then dlnc2=.;
  dlnc3=dif(log(robbery))-dlnp;  if first.jid then dlnc3=.;
  dlnc4=dif(log(assault))-dlnp;  if first.jid then dlnc4=.;
  dlnc5=dif(log(burglary))-dlnp; if first.jid then dlnc5=.;
  dlnc6=dif(log(larceny))-dlnp;  if first.jid then dlnc6=.;
  dlnc7=dif(log(auto))-dlnp;     if first.jid then dlnc7=.;

  dlns=dif(log(sworn))-dlnp;     if first.jid then dlns=.;
  dlns_1=lag(dlns);              if first.jid then dlns_1=.;
  dlns_2=lag(dlns_1);            if first.jid then dlns_2=.;

  *Levitt election measure;
  elec_1=lag(elecyear);          if first.jid then elec_1=.;
  elec_2=lag(elec_1);            if first.jid then elec_2=.;

  *McCrary election measure;
  may_1=lag(mayor);              if first.jid then may_1=.;
  may_2=lag(may_1);              if first.jid then may_2=.;

  *Levitt gubernatorial measure--no dispute here, checks out with;
  *ICPSR study # 7757 in all but one year;
  *I hardwire DC to always be zero, else gov missing for 69;
  *Doesnt really make a difference, but there it is;
  gov=governor;
  gov_1=lag(gov*(jid ne 33));    if first.jid then gov_1=.;
  gov_2=lag(gov_1);              if first.jid then gov_2=.;

/*City size dummies*/
  cs1=(1000000<=pop);
  cs2=( 500000<=pop<1000000);
  cs3=( 250000<=pop<500000);
  cs4=(      0< pop<250000);
/*Year dummies, y73-y92*/
  %do i=73 %to 92; %let yr=%eval(1900+&i); y&i=(year=&yr); %end;
/*Region dummies--
censdist missing for DC, so he hardwires DC to be in region 5*/
  if censdist=. then censdist=0; *DC;
  region=int(censdist/10)+5*(jid=33);
  %do i=1 %to 9; rr&i=(region=&i); %end;
/*City indicators*/
  %do i=1 %to 59; cc&i=(x=&i); %end;
/*Covariates*/
  dx1=dif(log(sta_welf))-dlnp;
  dx2=dif(log(sta_educ))-dlnp;
  dx3=dif(citybla);
  dx4=dif(cityfemh);
  dx5=dif(unemp);
  a15_24=a15_19+a20_24;
  dx6=dif(a15_24);

%do j=1 %to 7;
if dlnc&j ne . and dlns_1 ne . and dlns_2 ne . then nobs_&j=1;
else nobs_&j=0;
%end;
label city  ="Levitt city identifier"
      jid   ="McCrary city identifier"
      name  ="Levitt city name"
      cityname="McCrary city name"
      dlnc1 ="growth rate of murder p.c."
      dlnc2 ="growth rate of rape p.c."
      dlnc3 ="growth rate of robbery p.c."
      dlnc4 ="growth rate of assault p.c."
      dlnc5 ="growth rate of burglary p.c."
      dlnc6 ="growth rate of larceny p.c."
      dlnc7 ="growth rate of motor vehicle theft p.c."
      dlns_1="once-lagged growth rate of cops p.c."
      dlns_2="twice-lagged growth rate of cops p.c."
      elec_1="Levitt:once-lagged mayoral election year indicator"
      elec_2="Levitt:twice-lagged mayoral election year indicator"
      may_1 ="McCrary:once-lagged mayoral election year indicator"
      may_2 ="McCrary:twice-lagged mayoral election year indicator"
      gov_1 ="Levitt:once-lagged gubernatorial election year indicator"
      gov_2 ="Levitt:twice-lagged gubernatorial election year indicator"
      cs1   ="1,000,000<=pop"
      cs2   ="  500,000<=pop<1,000,000"
      cs3   ="  250,000<=pop<  500,000"
      cs4   ="           pop<  250,000"
%do i=73 %to 92;
      y&i ="Year is 19&i"
%end;
%do i=1 %to 9;
      rr&i  ="Region is &i"
%end;
%do i=1 %to 59;
      cc&i  ="City is &i (sort order jid=(state,alpha on city)"
%end;
%do i=1 %to 7;
      nobs_&i="=1 if dlnc&i is non-missing"
%end;
      dx1   ="growth rate of sta_welf p.c. (state level)"
      dx2   ="growth rate of sta_educ p.c. (state level)"
      dx3   ="difference in citybla (MSA level)"
      dx4   ="difference in cityfemh (MSA level)"
      dx5   ="difference in unemp (state level)"
      dx6   ="difference in fraction aged 15-24 (MSA level)";

if dlnc1 ne . & dlns_1 ne . & dlns_2 ne .;

run;

proc means data=crime2 noprint;
  var nobs_1-nobs_7;
  output out=test sum=;
proc print data=test;
proc means data=crime2;
run;
%mend;





















